==> bind-9.16.20-i586-1.txz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.bind.new:
if [ -e etc/rc.d/rc.bind ]; then
  cp -a etc/rc.d/rc.bind etc/rc.d/rc.bind.new.incoming
  cat etc/rc.d/rc.bind.new > etc/rc.d/rc.bind.new.incoming
  mv etc/rc.d/rc.bind.new.incoming etc/rc.d/rc.bind.new
fi

config etc/named.conf.new
config etc/rc.d/rc.bind.new

# Add a /var/named if it doesn't exist:
if [ ! -d var/named ]; then
  mkdir -p var/named
  chmod 755 var/named
fi

# Generate /etc/rndc.key if there's none there,
# and there also no /etc/rndc.conf (the other
# way to set this up).
if [ ! -r etc/rndc.key -a ! -r /etc/rndc.conf ]; then
  chroot . /sbin/ldconfig
  chroot . /usr/sbin/rndc-confgen -r /dev/urandom -a 2> /dev/null
fi
( cd usr/lib ; rm -rf libbind9.so )
( cd usr/lib ; ln -sf libbind9-9.16.20.so libbind9.so )
( cd usr/lib ; rm -rf libdns.so )
( cd usr/lib ; ln -sf libdns-9.16.20.so libdns.so )
( cd usr/lib ; rm -rf libirs.so )
( cd usr/lib ; ln -sf libirs-9.16.20.so libirs.so )
( cd usr/lib ; rm -rf libisc.so )
( cd usr/lib ; ln -sf libisc-9.16.20.so libisc.so )
( cd usr/lib ; rm -rf libisccc.so )
( cd usr/lib ; ln -sf libisccc-9.16.20.so libisccc.so )
( cd usr/lib ; rm -rf libisccfg.so )
( cd usr/lib ; ln -sf libisccfg-9.16.20.so libisccfg.so )
( cd usr/lib ; rm -rf libns.so )
( cd usr/lib ; ln -sf libns-9.16.20.so libns.so )
( cd usr/man/man1 ; rm -rf bind9-config.1.gz )
( cd usr/man/man1 ; ln -sf isc-config.sh.1.gz bind9-config.1.gz )
( cd usr/man/man8 ; rm -rf named-compilezone.8.gz )
( cd usr/man/man8 ; ln -sf named-checkzone.8.gz named-compilezone.8.gz )
( cd usr/man/man8 ; rm -rf tsig-keygen.8.gz )
( cd usr/man/man8 ; ln -sf ddns-confgen.8.gz tsig-keygen.8.gz )
( cd usr/sbin ; rm -rf lwresd )
( cd usr/sbin ; ln -sf named lwresd )
( cd usr/sbin ; rm -rf named-compilezone )
( cd usr/sbin ; ln -sf named-checkzone named-compilezone )
( cd usr/sbin ; rm -rf tsig-keygen )
( cd usr/sbin ; ln -sf ddns-confgen tsig-keygen )

==> bind-9.16.21-i586-2.txz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.bind.new:
if [ -e etc/rc.d/rc.bind ]; then
  cp -a etc/rc.d/rc.bind etc/rc.d/rc.bind.new.incoming
  cat etc/rc.d/rc.bind.new > etc/rc.d/rc.bind.new.incoming
  mv etc/rc.d/rc.bind.new.incoming etc/rc.d/rc.bind.new
fi

config etc/default/named.new
config etc/named.conf.new
config etc/rc.d/rc.bind.new

# Add a /var/named if it doesn't exist:
if [ ! -d var/named ]; then
  mkdir -p var/named
  chmod 755 var/named
fi

# Generate /etc/rndc.key if there's none there,
# and there's also no /etc/rndc.conf (the other
# way to set this up).
if [ ! -r etc/rndc.key -a ! -r /etc/rndc.conf ]; then
  chroot . /sbin/ldconfig
  chroot . /usr/sbin/rndc-confgen -a 2> /dev/null
  chroot . /bin/chown named:named /etc/rndc.key 2> /dev/null
fi
( cd usr/lib ; rm -rf libbind9.so )
( cd usr/lib ; ln -sf libbind9-9.16.21.so libbind9.so )
( cd usr/lib ; rm -rf libdns.so )
( cd usr/lib ; ln -sf libdns-9.16.21.so libdns.so )
( cd usr/lib ; rm -rf libirs.so )
( cd usr/lib ; ln -sf libirs-9.16.21.so libirs.so )
( cd usr/lib ; rm -rf libisc.so )
( cd usr/lib ; ln -sf libisc-9.16.21.so libisc.so )
( cd usr/lib ; rm -rf libisccc.so )
( cd usr/lib ; ln -sf libisccc-9.16.21.so libisccc.so )
( cd usr/lib ; rm -rf libisccfg.so )
( cd usr/lib ; ln -sf libisccfg-9.16.21.so libisccfg.so )
( cd usr/lib ; rm -rf libns.so )
( cd usr/lib ; ln -sf libns-9.16.21.so libns.so )
( cd usr/man/man1 ; rm -rf bind9-config.1.gz )
( cd usr/man/man1 ; ln -sf isc-config.sh.1.gz bind9-config.1.gz )
( cd usr/man/man8 ; rm -rf named-compilezone.8.gz )
( cd usr/man/man8 ; ln -sf named-checkzone.8.gz named-compilezone.8.gz )
( cd usr/man/man8 ; rm -rf tsig-keygen.8.gz )
( cd usr/man/man8 ; ln -sf ddns-confgen.8.gz tsig-keygen.8.gz )
( cd usr/sbin ; rm -rf lwresd )
( cd usr/sbin ; ln -sf named lwresd )
( cd usr/sbin ; rm -rf named-compilezone )
( cd usr/sbin ; ln -sf named-checkzone named-compilezone )
( cd usr/sbin ; rm -rf tsig-keygen )
( cd usr/sbin ; ln -sf ddns-confgen tsig-keygen )
